@@ -12,48 +12,40 @@ pub trait Entity<T: PartialEq> {
 
 #[derive(Debug, Clone)]
 pub struct ID(Uuid);
-impl ID {
-    pub fn new() -> Self {
-        Self(Uuid::new_v4())
-    }
 
-    pub fn from(uid: Uuid) -> Self {
-        Self(uid)
+impl AsMut<Uuid> for ID {
+    fn as_mut(&mut self) -> &mut Uuid {
+        &mut self.0
     }
+}
 
-    pub fn as_string(&self) -> String {
-        self.0.to_string()
-    }
-
-    pub fn inner(self) -> Uuid {
-        self.0
-    }
-
-    pub fn inner_ref(&self) -> &Uuid {
+impl AsRef<Uuid> for ID {
+    fn as_ref(&self) -> &Uuid {
         &self.0
     }
 }
 
-impl Into<ID> for Uuid {
-    fn into(self) -> ID {
-        ID::from(self)
+impl From<ID> for Uuid {
+    fn from(e: ID) -> Self {
+        e.0
     }
 }
-impl Into<Uuid> for ID {
-    fn into(self) -> Uuid {
-        self.inner()
+
+impl From<Uuid> for ID {
+    fn from(e: Uuid) -> Self {
+        Self(e)
     }
 }
 
 impl Default for ID {
     fn default() -> Self {
-        Self::new()
+        Self(Uuid::new_v4())
     }
 }
 
 impl Display for ID {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(f, "{}", self.as_string())
+        write!(f, "{}", self.0.to_string())
     }
 }
 
@@ -75,7 +67,7 @@ impl FromStr for ID {
 
 impl PartialEq for ID {
     fn eq(&self, other: &Self) -> bool {
-        self.as_string() == other.as_string()
+        self.to_string() == other.to_string()
     }
 }
 
@@ -84,7 +76,7 @@ impl Serialize for ID {
     where
         S: serde::Serializer,
     {
-        serializer.serialize_str(&self.as_string())
+        serializer.serialize_str(&self.to_string())
     }
 }
 
